summaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
authorAnders Roxell <anders.roxell@linaro.org>2014-02-23 22:04:04 +0100
committerAnders Roxell <anders.roxell@linaro.org>2014-02-25 11:44:50 +0100
commitf37cf255b5ff143520ed62736a70d4f9abade5ca (patch)
tree67e98c9ebd59841e63fc88dce152bf370fbd3818 /common
parent11c67f0014e064399488bac2cd552a7fb57b8f6c (diff)
common/scripts/netperf-client: tee to view output
Change-Id: If707fe2b58fc789411e4c2e093473c51c3f87541 Signed-off-by: Anders Roxell <anders.roxell@linaro.org>
Diffstat (limited to 'common')
-rwxr-xr-xcommon/scripts/netperf-client.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/common/scripts/netperf-client.sh b/common/scripts/netperf-client.sh
index 288cc0f..4d9ef7f 100755
--- a/common/scripts/netperf-client.sh
+++ b/common/scripts/netperf-client.sh
@@ -27,8 +27,8 @@ fi
ifconfig -a
ping -c 1 ${remote_ip} || exit 1
-ping -c 30 ${remote_ip} | ./common/scripts/netperf2LAVA.py
-for m in 64 128 256 512 1024 2048 4096 8192 16384; do netperf -H ${remote_ip} -l 20 -c -C -- -m $m -D; done | ./common/scripts/netperf2LAVA.py
-for m in 64 128 256 512 1024 2048 4096 8192 16384; do netperf -H ${remote_ip} -l 20 -t UDP_STREAM -c -C -- -m $m -D; done | ./common/scripts/netperf2LAVA.py
-for m in 1 32 64 128 512 1024 4096 8192 16384; do netperf -t TCP_RR -H ${remote_ip} -l 20 -c -C -- -r $m,$m -D; done | ./common/scripts/netperf2LAVA.py
-for m in 1 32 64 128 512 1024 4096 8192 16384; do netperf -t UDP_RR -H ${remote_ip} -l 20 -c -C -- -r $m,$m -D; done | ./common/scripts/netperf2LAVA.py
+ping -c 30 ${remote_ip} | tee ~/output.txt | ./common/scripts/netperf2LAVA.py
+for m in 64 128 256 512 1024 2048 4096 8192 16384; do netperf -H ${remote_ip} -l 20 -c -C -- -m $m -D; done | tee -a ~/output.txt | ./common/scripts/netperf2LAVA.py
+for m in 64 128 256 512 1024 2048 4096 8192 16384; do netperf -H ${remote_ip} -l 20 -t UDP_STREAM -c -C -- -m $m -D; done | tee -a ~/output.txt | ./common/scripts/netperf2LAVA.py
+for m in 1 32 64 128 512 1024 4096 8192 16384; do netperf -t TCP_RR -H ${remote_ip} -l 20 -c -C -- -r $m,$m -D; done | tee -a ~/output.txt | ./common/scripts/netperf2LAVA.py
+for m in 1 32 64 128 512 1024 4096 8192 16384; do netperf -t UDP_RR -H ${remote_ip} -l 20 -c -C -- -r $m,$m -D; done | tee -a ~/output.txt | ./common/scripts/netperf2LAVA.py